@@ -1,5 +1,5 @@
-__version__ = "2.7.0"
-__keywords__ = ["aes cipher"]
+__version__ = "3.1.0"
+__keywords__ = ["aes cipher cbc ctr stream block encrypt decrypt"]
 
 
 if not __version__.endswith(".0"):
@@ -10,5 +10,7 @@ if not __version__.endswith(".0"):
     os._exit(1)
 
 
-from .core import *
+from .cbc import *
+from .ctr import *
+from .utils import AESCipherCTRFileEncReader, AESCipherCTRFileEncWriter, AESCipherCTRFileDecReader, AESCipherCTRFileDecWriter
 
